

#ifndef DEFHSDRGJHFGSD_123253465
#define DEFHSDRGJHFGSD_123253465

//
// PXA255 LCD Controller Register and Bit Definitions
//
#include <drivers/lcd/types.h>


//---------------------------------------
// LCD Controller
#define LCD_BASE			0x44000000
#define LCD_REG(_x_)		*(vulong *)(LCD_BASE + _x_)	

//---------------------------------------
//     LCD Controller Register Offsets
#define LCD_LCCR0      			0x000          				// LCD controller control register 0
#define LCD_LCCR1      			0x004          				// LCD controller control register 1
#define LCD_LCCR2      			0x008          				// LCD controller control register 2
#define LCD_LCCR3      			0x00C          				// LCD controller control register 3
#define LCD_TRGBR      			0x040          				// TMED RGB Seed Register
#define LCD_TCR        			0x044          				// TMED Control Register
#define LCD_FDADR0     			0x200          				// DMA channel 0 frame descriptor address register
#define LCD_FSADR0     			0x204          				// DMA channel 0 frame source address register
#define LCD_FIDR0      			0x208          				// DMA channel 0 frame ID register
#define LCD_LDCMD0     			0x20C          				// DMA channel 0 command register
#define LCD_FDADR1     			0x210          				// DMA channel 1 frame descriptor address register
#define LCD_FSADR1     			0x214          				// DMA channel 1 frame source address register
#define LCD_FIDR1      			0x218          				// DMA channel 1 frame ID register
#define LCD_LDCMD1     			0x21C          				// DMA channel 1 command register
#define LCD_FBR0       			0x020          				// DMA channel 0 frame branch register
#define LCD_FBR1       			0x024          				// DMA channel 1 frame branch register
#define LCD_LCSR       			0x038          				// LCD controller status register
#define LCD_LIIDR      			0x03C          				// LCD controller interrupt ID register


// LCD controller control register 0
#define LCCR0_OUM 				BIT21						// Output FIFO Underrun Mask, 1 = no interrupt
#define LCCR0_BM 				BIT20						// Branch Mask
#define LCCR0_PDD(_x_)			((_x_ & 0xfff) << 12)		// Palette DMA Request Delay
#define LCCR0_QDM				BIT11						// Quick Disable Interrupt Mask, 1 = no interrupt
#define LCCR0_DIS				BIT10						// LCD Disable Status
#define LCCR0_DPD				BIT9						// Double-Pixel Data (DPD) pin mode (must be 0 for TFT)
#define LCCR0_PAS				BIT7						// Passive/Active Display select 1 = TFT
#define LCCR0_EFM				BIT6						// End of Frame Interrupt Mask, 1 = no interrupt
#define LCCR0_IUM				BIT5						// Input FIFO Underrun Mask, 1 = no interrupt
#define LCCR0_SFM				BIT4						// Start of Frame Mask, 1 = no interrupt
#define LCCR0_LDM				BIT3						// LCD Disable Done Mask, 1 = no interrupt
#define LCCR0_SDS				BIT2						// Single-/Dual-panel Display Select, 1 = Dual (must be 0 for TFT)
#define LCCR0_CMS				BIT1						// Color/Monochrome Select, 1 = Monochrome
#define LCCR0_ENB				BIT0						// LCD Controller Enable, 1 = Enable

// LCD controller control register 1
#define LCCR1_BLW(_x_)			((_x_ & 0xff) << 24)		// Beginning-of-Line pixel clock Wait count = BLW + 1
#define LCCR1_ELW(_x_)			((_x_ & 0xff) << 16)		// End-of-line pixel clock wait count = ELW + 1
#define LCCR1_HSW(_x_)			((_x_ & 0x3f) << 10)		// Horizontal sync pulse width = HSW + 1
#define LCCR1_PPL(_x_)			(((_x_) & 0x3ff) << 0)		// Pixels per line = PPL + 1

// LCD controller control register 2
#define LCCR2_BFW(_x_)			((_x_ & 0xff) << 24)		// Beginning-of-frame line clock wait count
#define LCCR2_EFW(_x_)			((_x_ & 0xff) << 16)		// End-of-frame line clock wait count
#define LCCR2_VSW(_x_)			((_x_ & 0x3f) << 10)		// Vertical sync pulse width = VSW + 1
#define LCCR2_LPP(_x_)			(((_x_) & 0x3ff) << 0)		// Lines per panel = LPP + 1

// LCD controller control register 3
#define LCCR3_DPC				BIT27						// Double Pixel Clock mode, 1 = LCLK = 2*PCD
#define LCCR3_BPP_1				(0x0 << 24) 				// 1-bits/pixel [4 entry, 8 byte palette buffer]
#define LCCR3_BPP_2				(0x1 << 24) 				// 2-bits/pixel [4 entry, 8 byte palette buffer]
#define LCCR3_BPP_4				(0x2 << 24) 				// 4-bits/pixel [16 entry, 32 byte palette buffer]
#define LCCR3_BPP_8				(0x3 << 24) 				// 8-bits/pixel [256 entry, 512 byte palette buffer]
#define LCCR3_BPP_16			(0x4 << 24)					// 16-bits/pixel [no palette buffer]
#define LCCR3_OEP				BIT23						// Output Enable Polarity, 0 = L_BIAS is Active High
#define LCCR3_PCP				BIT22						// Pixel Clock Polarity, 0 = LCD Data is Sampled on Rising Edge
#define LCCR3_HSP				BIT21						// Horizontal Sync Polarity, 0 = L_LCLK is Active High
#define LCCR3_VSP				BIT20						// Vertical Sync Polarity, L_FCLK is Active High
#define LCCR3_API(_x_)			((_x_ & 0xf) << 16)			// AC bias Pin transitions per Interrupt.
#define LCCR3_ACB(_x_)			((_x_ & 0xff) << 8)			// AC Bias pin frequency
#define LCCR3_PCD(_x_)			((_x_ & 0xff) << 0)			// Pixel Clock Divisor, Pixel Clock Frequency = LCLK/(2*(PCD+1)).

// LCD controller status register - These also clear the corresponding
// interrupt condition when a one is written to the bit
#define LCSR_SINT				BIT10						// Subsequent Interrupt status, maskable interrupt
#define LCSR_BS					BIT9						// Branch Status, maskable interrupt
#define LCSR_EOF				BIT8						// End Of Frame status, maskable interrupt
#define LCSR_QD					BIT7						// LCD Quick Disable status, maskable interrupt
#define LCSR_OU					BIT6						// Output FIFO Underrun status, maskable interrupt
#define LCSR_IUU				BIT5						// Input FIFO Underrun Upper panel status, maskable interrupt
#define LCSR_IUL				BIT4						// Input FIFO Underrun Lower panel status, maskable interrupt
#define LCSR_ABC				BIT3						// AC Bias Count status, nonmaskable interrupt
#define LCSR_BER				BIT2						// Bus error status, nonmaskable interrupt
#define LCSR_SOF				BIT1						// Start Of Frame status, maskable interrupt
#define LCSR_LDD				BIT0						// LCD Disable Done status, maskable interrupt

// 16-bit pixels are RGB 565 - LSB of RED and BLUE are tied low at the 
// LCD Interface, while the LSB of GREEN is loaded as 0



#if INCLUDE_CCD_CAMERA
	#define RED_SUBPIXEL(n)		(n & 0xf8) << 8
	#define GREEN_SUBPIXEL(n)	             (n & 0xfc) << 3
	#define BLUE_SUBPIXEL(n)	             (n & 0xf8) >>3
#else
	#define RED_SUBPIXEL(n)		(n & 0x1f) << 11
	#define GREEN_SUBPIXEL(n)	(n & 0x1f) << 6
	#define BLUE_SUBPIXEL(n)	(n & 0x1f) << 0
#endif


// define a simple VGA style 16-color pallette
#define	LU_BLACK		RED_SUBPIXEL(0x00) | GREEN_SUBPIXEL(0x00) | BLUE_SUBPIXEL(0x00)
#define	LU_BLUE			RED_SUBPIXEL(0x0f) | GREEN_SUBPIXEL(0x00) | BLUE_SUBPIXEL(0x00)
#define	LU_GREEN		RED_SUBPIXEL(0x00) | GREEN_SUBPIXEL(0x0f) | BLUE_SUBPIXEL(0x00)
#define	LU_CYAN			RED_SUBPIXEL(0x00) | GREEN_SUBPIXEL(0x0f) | BLUE_SUBPIXEL(0x0f)
#define	LU_RED			RED_SUBPIXEL(0x0f) | GREEN_SUBPIXEL(0x00) | BLUE_SUBPIXEL(0x00)
#define	LU_VIOLET		RED_SUBPIXEL(0x0f) | GREEN_SUBPIXEL(0x00) | BLUE_SUBPIXEL(0x0f)
#define	LU_YELLOW		RED_SUBPIXEL(0x0f) | GREEN_SUBPIXEL(0x0f) | BLUE_SUBPIXEL(0x00)
#define	LU_GREY			RED_SUBPIXEL(0x0f) | GREEN_SUBPIXEL(0x0f) | BLUE_SUBPIXEL(0x0f)
#define	LU_WHITE		RED_SUBPIXEL(0x17) | GREEN_SUBPIXEL(0x17) | BLUE_SUBPIXEL(0x17)
#define	LU_BRT_BLUE		RED_SUBPIXEL(0x00) | GREEN_SUBPIXEL(0x00) | BLUE_SUBPIXEL(0x1f)
#define	LU_BRT_GREEN	RED_SUBPIXEL(0x00) | GREEN_SUBPIXEL(0x1f) | BLUE_SUBPIXEL(0x00)
#define	LU_BRT_CYAN		RED_SUBPIXEL(0x00) | GREEN_SUBPIXEL(0x1f) | BLUE_SUBPIXEL(0x1f)
#define	LU_BRT_RED		RED_SUBPIXEL(0x1f) | GREEN_SUBPIXEL(0x00) | BLUE_SUBPIXEL(0x00)
#define	LU_BRT_VIOLET	RED_SUBPIXEL(0x1f) | GREEN_SUBPIXEL(0x00) | BLUE_SUBPIXEL(0x1f)
#define	LU_BRT_YELLOW	RED_SUBPIXEL(0x00) | GREEN_SUBPIXEL(0x1f) | BLUE_SUBPIXEL(0x1f)
#define	LU_BRT_WHITE	RED_SUBPIXEL(0x1f) | GREEN_SUBPIXEL(0x1f) | BLUE_SUBPIXEL(0x1f)

#ifndef PXA255_H
#define PXA255_H

//int lcd_init(int);
//void LcdPoint8(unsigned long,unsigned long,uchar);
//void LcdPoint16(unsigned long,unsigned long,ushort);

//void lcd_putchar(char c);

const ushort vga_lookup[] = {
LU_BLACK,		
LU_BLUE,			
LU_GREEN,		
LU_CYAN,			
LU_RED,			
LU_VIOLET,		
LU_YELLOW,		
LU_GREY,			
LU_WHITE,		
LU_BRT_BLUE,		
LU_BRT_GREEN,	
LU_BRT_CYAN,		
LU_BRT_RED,		
LU_BRT_VIOLET,
LU_BRT_YELLOW,
LU_BRT_WHITE	
};

const uchar lcd_lut[256][3] = {
//    RED,  GREEN, BLUE		// Entry
	{ 0xF0,  0x00, 0x00, },	// 00  
	{ 0x00,  0x00, 0xA0, },	// 01 
	{ 0x00,  0xA0, 0x00, },	// 02 
	{ 0x00,  0xA0, 0xA0, },	// 03 
	{ 0xA0,  0x00, 0x00, },	// 04 
	{ 0xA0,  0x00, 0xA0, },	// 05 
	{ 0xA0,  0xA0, 0x00, },	// 06 
	{ 0xA0,  0xA0, 0xA0, },	// 07 
	{ 0x50,  0x50, 0x50, },	// 08 
	{ 0x50,  0x50, 0xF0, },	// 09 
	{ 0x50,  0xF0, 0x50, },	// 0A 
	{ 0x50,  0xF0, 0xF0, },	// 0B 
	{ 0xF0,  0x50, 0x50, },	// 0C 
	{ 0xF0,  0x50, 0xF0, },	// 0D 
	{ 0xF0,  0xF0, 0x50, },	// 0E 
	{ 0xF0,  0xF0, 0xF0, },	// 0F 
	{ 0x00,  0x00, 0x00, },	// 10 
	{ 0x10,  0x10, 0x10, },	// 11 
	{ 0x20,  0x20, 0x20, },	// 12 
	{ 0x20,  0x20, 0x20, },	// 13 
	{ 0x30,  0x30, 0x30, },	// 14 
	{ 0x40,  0x40, 0x40, },	// 15 
	{ 0x50,  0x50, 0x50, },	// 16 
	{ 0x60,  0x60, 0x60, },	// 17 
	{ 0x70,  0x70, 0x70, },	// 18 
	{ 0x80,  0x80, 0x80, },	// 19 
	{ 0x90,  0x90, 0x90, },	// 1A 
	{ 0xA0,  0xA0, 0xA0, },	// 1B 
	{ 0xB0,  0xB0, 0xB0, },	// 1C 
	{ 0xC0,  0xC0, 0xC0, },	// 1D 
	{ 0xE0,  0xE0, 0xE0, },	// 1E 
	{ 0xF0,  0xF0, 0xF0, },	// 1F 
	{ 0x00,  0x00, 0xF0, },	// 20 
	{ 0x40,  0x00, 0xF0, },	// 21 
	{ 0x70,  0x00, 0xF0, },	// 22 
	{ 0xB0,  0x00, 0xF0, },	// 23 
	{ 0xF0,  0x00, 0xF0, },	// 24 
	{ 0xF0,  0x00, 0xB0, },	// 25 
	{ 0xF0,  0x00, 0x70, },	// 26 
	{ 0xF0,  0x00, 0x40, },	// 27 
	{ 0xF0,  0x00, 0x00, },	// 28 
	{ 0xF0,  0x40, 0x00, },	// 29 
	{ 0xF0,  0x70, 0x00, },	// 2A 
	{ 0xF0,  0xB0, 0x00, },	// 2B 
	{ 0xF0,  0xF0, 0x00, },	// 2C 
	{ 0xB0,  0xF0, 0x00, },	// 2D 
	{ 0x70,  0xF0, 0x00, },	// 2E 
	{ 0x40,  0xF0, 0x00, },	// 2F 
	{ 0x00,  0xF0, 0x00, },	// 30 
	{ 0x00,  0xF0, 0x40, },	// 31 
	{ 0x00,  0xF0, 0x70, },	// 32 
	{ 0x00,  0xF0, 0xB0, },	// 33 
	{ 0x00,  0xF0, 0xF0, },	// 34 
	{ 0x00,  0xB0, 0xF0, },	// 35 
	{ 0x00,  0x70, 0xF0, },	// 36 
	{ 0x00,  0x40, 0xF0, },	// 37 
	{ 0x70,  0x70, 0xF0, },	// 38 
	{ 0x90,  0x70, 0xF0, },	// 39 
	{ 0xB0,  0x70, 0xF0, },	// 3A 
	{ 0xD0,  0x70, 0xF0, },	// 3B 
	{ 0xF0,  0x70, 0xF0, },	// 3C 
	{ 0xF0,  0x70, 0xD0, },	// 3D 
	{ 0xF0,  0x70, 0xB0, },	// 3E 
	{ 0xF0,  0x70, 0x90, },	// 3F 
	{ 0xF0,  0x70, 0x70, },	// 40 
	{ 0xF0,  0x90, 0x70, },	// 41 
	{ 0xF0,  0xB0, 0x70, },	// 42 
	{ 0xF0,  0xD0, 0x70, },	// 43 
	{ 0xF0,  0xF0, 0x70, },	// 44 
	{ 0xD0,  0xF0, 0x70, },	// 45 
	{ 0xB0,  0xF0, 0x70, },	// 46 
	{ 0x90,  0xF0, 0x70, },	// 47 
	{ 0x70,  0xF0, 0x70, },	// 48 
	{ 0x70,  0xF0, 0x90, },	// 49 
	{ 0x70,  0xF0, 0xB0, },	// 4A 
	{ 0x70,  0xF0, 0xD0, },	// 4B 
	{ 0x70,  0xF0, 0xF0, },	// 4C 
	{ 0x70,  0xD0, 0xF0, },	// 4D 
	{ 0x70,  0xB0, 0xF0, },	// 4E 
	{ 0x70,  0x90, 0xF0, },	// 4F 
	{ 0xB0,  0xB0, 0xF0, },	// 50 
	{ 0xC0,  0xB0, 0xF0, },	// 51 
	{ 0xD0,  0xB0, 0xF0, },	// 52 
	{ 0xE0,  0xB0, 0xF0, },	// 53 
	{ 0xF0,  0xB0, 0xF0, },	// 54 
	{ 0xF0,  0xB0, 0xE0, },	// 55 
	{ 0xF0,  0xB0, 0xD0, },	// 56 
	{ 0xF0,  0xB0, 0xC0, },	// 57 
	{ 0xF0,  0xB0, 0xB0, },	// 58 
	{ 0xF0,  0xC0, 0xB0, },	// 59 
	{ 0xF0,  0xD0, 0xB0, },	// 5A 
	{ 0xF0,  0xE0, 0xB0, },	// 5B 
	{ 0xF0,  0xF0, 0xB0, },	// 5C 
	{ 0xE0,  0xF0, 0xB0, },	// 5D 
	{ 0xD0,  0xF0, 0xB0, },	// 5E 
	{ 0xC0,  0xF0, 0xB0, },	// 5F 
	{ 0xB0,  0xF0, 0xB0, },	// 60 
	{ 0xB0,  0xF0, 0xC0, },	// 61 
	{ 0xB0,  0xF0, 0xD0, },	// 62 
	{ 0xB0,  0xF0, 0xE0, },	// 63 
	{ 0xB0,  0xF0, 0xF0, },	// 64 
	{ 0xB0,  0xE0, 0xF0, },	// 65 
	{ 0xB0,  0xD0, 0xF0, },	// 66 
	{ 0xB0,  0xC0, 0xF0, },	// 67 
	{ 0x00,  0x00, 0x70, },	// 68 
	{ 0x10,  0x00, 0x70, },	// 69 
	{ 0x30,  0x00, 0x70, },	// 6A 
	{ 0x50,  0x00, 0x70, },	// 6B 
	{ 0x70,  0x00, 0x70, },	// 6C 
	{ 0x70,  0x00, 0x50, },	// 6D 
	{ 0x70,  0x00, 0x30, },	// 6E 
	{ 0x70,  0x00, 0x10, },	// 6F 
	{ 0x70,  0x00, 0x00, },	// 70 
	{ 0x70,  0x10, 0x00, },	// 71 
	{ 0x70,  0x30, 0x00, },	// 72 
	{ 0x70,  0x50, 0x00, },	// 73 
	{ 0x70,  0x70, 0x00, },	// 74 
	{ 0x50,  0x70, 0x00, },	// 75 
	{ 0x30,  0x70, 0x00, },	// 76 
	{ 0x10,  0x70, 0x00, },	// 77 
	{ 0x00,  0x70, 0x00, },	// 78 
	{ 0x00,  0x70, 0x10, },	// 79 
	{ 0x00,  0x70, 0x30, },	// 7A 
	{ 0x00,  0x70, 0x50, },	// 7B 
	{ 0x00,  0x70, 0x70, },	// 7C 
	{ 0x00,  0x50, 0x70, },	// 7D 
	{ 0x00,  0x30, 0x70, },	// 7E 
	{ 0x00,  0x10, 0x70, },	// 7F 
	{ 0x30,  0x30, 0x70, },	// 80 
	{ 0x40,  0x30, 0x70, },	// 81 
	{ 0x50,  0x30, 0x70, },	// 82 
	{ 0x60,  0x30, 0x70, },	// 83 
	{ 0x70,  0x30, 0x70, },	// 84 
	{ 0x70,  0x30, 0x60, },	// 85 
	{ 0x70,  0x30, 0x50, },	// 86 
	{ 0x70,  0x30, 0x40, },	// 87 
	{ 0x70,  0x30, 0x30, },	// 88 
	{ 0x70,  0x40, 0x30, },	// 89 
	{ 0x70,  0x50, 0x30, },	// 8A 
	{ 0x70,  0x60, 0x30, },	// 8B 
	{ 0x70,  0x70, 0x30, },	// 8C 
	{ 0x60,  0x70, 0x30, },	// 8D 
	{ 0x50,  0x70, 0x30, },	// 8E 
	{ 0x40,  0x70, 0x30, },	// 8F 
	{ 0x30,  0x70, 0x30, },	// 90 
	{ 0x30,  0x70, 0x40, },	// 91 
	{ 0x30,  0x70, 0x50, },	// 92 
	{ 0x30,  0x70, 0x60, },	// 93 
	{ 0x30,  0x70, 0x70, },	// 94 
	{ 0x30,  0x60, 0x70, },	// 95 
	{ 0x30,  0x50, 0x70, },	// 96 
	{ 0x30,  0x40, 0x70, },	// 97 
	{ 0x50,  0x50, 0x70, },	// 98 
	{ 0x50,  0x50, 0x70, },	// 99 
	{ 0x60,  0x50, 0x70, },	// 9A 
	{ 0x60,  0x50, 0x70, },	// 9B 
	{ 0x70,  0x50, 0x70, },	// 9C 
	{ 0x70,  0x50, 0x60, },	// 9D 
	{ 0x70,  0x50, 0x60, },	// 9E 
	{ 0x70,  0x50, 0x50, },	// 9F 
	{ 0x70,  0x50, 0x50, },	// A0 
	{ 0x70,  0x50, 0x50, },	// A1 
	{ 0x70,  0x60, 0x50, },	// A2 
	{ 0x70,  0x60, 0x50, },	// A3 
	{ 0x70,  0x70, 0x50, },	// A4 
	{ 0x60,  0x70, 0x50, },	// A5 
	{ 0x60,  0x70, 0x50, },	// A6 
	{ 0x50,  0x70, 0x50, },	// A7 
	{ 0x50,  0x70, 0x50, },	// A8 
	{ 0x50,  0x70, 0x50, },	// A9 
	{ 0x50,  0x70, 0x60, },	// AA 
	{ 0x50,  0x70, 0x60, },	// AB 
	{ 0x50,  0x70, 0x70, },	// AC 
	{ 0x50,  0x60, 0x70, },	// AD 
	{ 0x50,  0x60, 0x70, },	// AE 
	{ 0x50,  0x50, 0x70, },	// AF 
	{ 0x00,  0x00, 0x40, },	// B0 
	{ 0x10,  0x00, 0x40, },	// B1 
	{ 0x20,  0x00, 0x40, },	// B2 
	{ 0x30,  0x00, 0x40, },	// B3 
	{ 0x40,  0x00, 0x40, },	// B4 
	{ 0x40,  0x00, 0x30, },	// B5 
	{ 0x40,  0x00, 0x20, },	// B6 
	{ 0x40,  0x00, 0x10, },	// B7 
	{ 0x40,  0x00, 0x00, },	// B8 
	{ 0x40,  0x10, 0x00, },	// B9 
	{ 0x40,  0x20, 0x00, },	// BA 
	{ 0x40,  0x30, 0x00, },	// BB 
	{ 0x40,  0x40, 0x00, },	// BC 
	{ 0x30,  0x40, 0x00, },	// BD 
	{ 0x20,  0x40, 0x00, },	// BE 
	{ 0x10,  0x40, 0x00, },	// BF 
	{ 0x00,  0x40, 0x00, },	// C0 
	{ 0x00,  0x40, 0x10, },	// C1 
	{ 0x00,  0x40, 0x20, },	// C2 
	{ 0x00,  0x40, 0x30, },	// C3 
	{ 0x00,  0x40, 0x40, },	// C4 
	{ 0x00,  0x30, 0x40, },	// C5 
	{ 0x00,  0x20, 0x40, },	// C6 
	{ 0x00,  0x10, 0x40, },	// C7 
	{ 0x20,  0x20, 0x40, },	// C8 
	{ 0x20,  0x20, 0x40, },	// C9 
	{ 0x30,  0x20, 0x40, },	// CA 
	{ 0x30,  0x20, 0x40, },	// CB 
	{ 0x40,  0x20, 0x40, },	// CC 
	{ 0x40,  0x20, 0x30, },	// CD 
	{ 0x40,  0x20, 0x30, },	// CE 
	{ 0x40,  0x20, 0x20, },	// CF 
	{ 0x40,  0x20, 0x20, },	// D0 
	{ 0x40,  0x20, 0x20, },	// D1 
	{ 0x40,  0x30, 0x20, },	// D2 
	{ 0x40,  0x30, 0x20, },	// D3 
	{ 0x40,  0x40, 0x20, },	// D4 
	{ 0x30,  0x40, 0x20, },	// D5 
	{ 0x30,  0x40, 0x20, },	// D6 
	{ 0x20,  0x40, 0x20, },	// D7 
	{ 0x20,  0x40, 0x20, },	// D8 
	{ 0x20,  0x40, 0x20, },	// D9 
	{ 0x20,  0x40, 0x30, },	// DA 
	{ 0x20,  0x40, 0x30, },	// DB 
	{ 0x20,  0x40, 0x40, },	// DC 
	{ 0x20,  0x30, 0x40, },	// DD 
	{ 0x20,  0x30, 0x40, },	// DE 
	{ 0x20,  0x20, 0x40, },	// DF 
	{ 0x20,  0x20, 0x40, },	// E0 
	{ 0x30,  0x20, 0x40, },	// E1 
	{ 0x30,  0x20, 0x40, },	// E2 
	{ 0x30,  0x20, 0x40, },	// E3 
	{ 0x40,  0x20, 0x40, },	// E4 
	{ 0x40,  0x20, 0x30, },	// E5 
	{ 0x40,  0x20, 0x30, },	// E6 
	{ 0x40,  0x20, 0x30, },	// E7 
	{ 0x40,  0x20, 0x20, },	// E8 
	{ 0x40,  0x30, 0x20, },	// E9 
	{ 0x40,  0x30, 0x20, },	// EA 
	{ 0x40,  0x30, 0x20, },	// EB 
	{ 0x40,  0x40, 0x20, },	// EC 
	{ 0x30,  0x40, 0x20, },	// ED 
	{ 0x30,  0x40, 0x20, },	// EE 
	{ 0x30,  0x40, 0x20, },	// EF 
	{ 0x20,  0x40, 0x20, },	// F0 
	{ 0x20,  0x40, 0x30, },	// F1 
	{ 0x20,  0x40, 0x30, },	// F2 
	{ 0x20,  0x40, 0x30, },	// F3 
	{ 0x20,  0x40, 0x40, },	// F4 
	{ 0x20,  0x30, 0x40, },	// F5 
	{ 0x20,  0x30, 0x40, },	// F6 
	{ 0x20,  0x30, 0x40, },	// F7 
	{ 0x00,  0x00, 0x00, },	// F8 
	{ 0x00,  0x00, 0x00, },	// F9 
	{ 0x00,  0x00, 0x00, },	// FA 
	{ 0x00,  0x00, 0x00, },	// FB 
	{ 0x00,  0x00, 0x00, },	// FC 
	{ 0x00,  0x00, 0x00, },	// FD 
	{ 0x00,  0x00, 0x00, },	// FE 
	{ 0x00,  0x00, 0x00, },	// FF 
};

// pjk 030925

const uchar lcd_lut1[16][3] = {
//    	  RED,  GREEN, BLUE		// Entry
	{ 0x00,  0x00, 0x00, },	// 00  
	{ 0xFF,  0x00, 0x00, },	// 01 
	{ 0x00,  0xFF, 0x00, },	// 02 
	{ 0x00,  0x00, 0xFF, },	// 03 
	{ 0xFF,  0xFF, 0x00, },	// 04 
	{ 0xFF,  0x00, 0xFF, },	// 05 
	{ 0x00,  0xFF, 0xFF, },	// 06 
	{ 0x88,  0x00, 0x00, },	// 07 
	{ 0x00,  0x88, 0x00, },	// 08 
	{ 0x00,  0x00, 0x88, },	// 09 
	{ 0x88,  0x88, 0x00, },	// 0A 
	{ 0x00,  0x88, 0x88, },	// 0B 
	{ 0x88,  0x00, 0x88, },	// 0C 
	{ 0x88,  0x88, 0x88, },	// 0D 
	{ 0xAA,  0xAA, 0xAA, },	// 0E 
	{ 0xFF,  0xFF, 0xFF, },	// 0F 
};

#define LCD_PDR_ADD             0xa3000000
#define LCD_PDR(_x_)    *(vulong *)(LCD_PDR_ADD + _x_)  // Palette Descriptor, Palette Buffer

#define LCD_FDR_ADD             0xa3000010
#define LCD_FDR(_x_)    *(vulong *)(LCD_FDR_ADD + _x_)  // Frame Descriptor, Frame Buffer

#define LCD_PAL_ADD             0xa3000020
#define LCD_PAL(_x_)    *(vushort *)(LCD_PAL_ADD + _x_) // Palette Buffer


#define LCD_BUF_ADD             0xa3000400
#define LCD_BUF(_x_)    *(vushort *)(LCD_BUF_ADD + _x_) // Frame Buffer


#endif //PXA255_H


#endif //DEFHSDRGJHFGSD_123253465
